##  Modifying To-Do Items
In the collaboration tab, you can edit to-do items that were created by you. To edit a to-do item, do the following:
  1. Access to-dos from the navigation bar by selecting More and then choosing To-Dos.
  2. Hover over the to-do item you need to modify, and click on the edit icon represented by a pen. This action opens an overlay where you can make your edits.
![Modifying a To-Do Item](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2746baf17a441014896acab1865b5c9e_LowRes.png)
Modifying a To-Do Item
  3. After making the needed changes, click Save.


**Note**
Admins can modify any to-do items in the administration area. To learn more, see [Modifying To-Do Items](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275dbdde7a4410148637f298598afe49__modifying_to-do_items).
